@@ -2,6 +2,8 @@ from typing import MutableMapping, Optional, Union
 
 from redis import ConnectionPool
 from redis.asyncio.client import Pipeline as RedisPipeline
+from redis.asyncio.cluster import ClusterPipeline as RedisClusterPipeline
+from redis.asyncio.cluster import RedisCluster
 
 from tair.commands import TairCommands
 from tair.typing import ResponseCallbackT
@@ -22,3 +24,8 @@ class Pipeline(RedisPipeline, TairCommands):
             transaction=transaction,
             shard_hint=shard_hint,
         )
+
+
+class ClusterPipeline(RedisClusterPipeline, TairCommands):
+    def __init__(self, client: RedisCluster):
+        RedisClusterPipeline.__init__(self, client)
